.. vim: set ft=rst fenc=utf-8 tw=72 nowrap:
.. Version: pynfact-1.3.1rc2

##################
User documentation
##################

.. rubric:: A static web generator in Python

**Welcome to PynFact!**

.. image:: logo.png
    :align: center

Project links
=============

* Current version: **1.3.1rc2**
* `GitHub project page`_
* `The Python Package Index (PyPI) repository`_

Contents
========

.. toctree::
    :maxdepth: 2

    intro
    dependencies
    quickstart
    install-and-upgrade
    configuration
    site-content
    document-syntax
    error-codes
    versioning


.. _`GitHub project page`:
    https://github.com/jacorbal/pynfact

.. _`The Python Package Index (PyPI) repository`:
    https://github.com/jacorbal/pynfact
